@@ -901,6 +901,7 @@ asn1_der_decoding (asn1_node * element, const void *ider, int ider_len,
   unsigned char class;
   unsigned long tag;
   int indefinite, result;
+  int tag_len;
   const unsigned char *der = ider;
 
   node = *element;
@@ -923,6 +924,7 @@ asn1_der_decoding (asn1_node * element, const void *ider, int ider_len,
   p = node;
   while (1)
     {
+      tag_len = 0;
       ris = ASN1_SUCCESS;
       if (move != UP)
 	{
@@ -1050,7 +1052,7 @@ asn1_der_decoding (asn1_node * element, const void *ider, int ider_len,
 
 	  if (ris == ASN1_SUCCESS)
 	    ris =
-	      extract_tag_der_recursive (p, der + counter, ider_len, &len2);
+	      extract_tag_der_recursive (p, der + counter, ider_len, &tag_len);
 
 	  if (ris != ASN1_SUCCESS)
 	    {
@@ -1076,8 +1078,8 @@ asn1_der_decoding (asn1_node * element, const void *ider, int ider_len,
 	    }
 	  else
 	    {
-	      DECR_LEN(ider_len, len2);
-	      counter += len2;
+	      DECR_LEN(ider_len, tag_len);
+	      counter += tag_len;
 	    }
 	}
 
@@ -1358,6 +1360,12 @@ asn1_der_decoding (asn1_node * element, const void *ider, int ider_len,
 	      move = RIGHT;
 	      break;
 	    case ASN1_ETYPE_ANY:
+	      /* Check indefinite lenth method in an EXPLICIT TAG */
+	      if ((p->type & CONST_TAG) && tag_len == 2 && (der[counter - 1] == 0x80))
+		indefinite = 1;
+	      else
+	        indefinite = 0;
+
 	      if (asn1_get_tag_der
 		  (der + counter, ider_len, &class, &len2,
 		   &tag) != ASN1_SUCCESS)
@@ -1397,12 +1405,6 @@ asn1_der_decoding (asn1_node * element, const void *ider, int ider_len,
 		      goto cleanup;
 		    }
 
-		  /* Check indefinite lenth method in an EXPLICIT TAG */
-		  if ((p->type & CONST_TAG) && (der[counter - 1] == 0x80))
-		    indefinite = 1;
-		  else
-		    indefinite = 0;
-
 		  result =
 		    _asn1_get_indefinite_length_string (der + counter, ider_len, &len2);
 		  if (result != ASN1_SUCCESS)
@@ -1415,23 +1417,25 @@ asn1_der_decoding (asn1_node * element, const void *ider, int ider_len,
 		  _asn1_set_value_lv (p, der + counter, len2);
 		  counter += len2;
 
-		  /* Check if a couple of 0x00 are present due to an EXPLICIT TAG with
-		     an indefinite length method. */
-		  if (indefinite)
-		    {
-	              DECR_LEN(ider_len, 2);
-		      if (!der[counter] && !der[counter + 1])
-			{
-			  counter += 2;
-			}
-		      else
-			{
-			  result = ASN1_DER_ERROR;
-                          warn();
-			  goto cleanup;
-			}
-		    }
 		}
+
+	        /* Check if a couple of 0x00 are present due to an EXPLICIT TAG with
+	           an indefinite length method. */
+	        if (indefinite)
+		  {
+	            DECR_LEN(ider_len, 2);
+		    if (!der[counter] && !der[counter + 1])
+		      {
+		        counter += 2;
+		      }
+		    else
+		      {
+		        result = ASN1_DER_ERROR;
+                        warn();
+		        goto cleanup;
+		      }
+		  }
+
 	      move = RIGHT;
 	      break;
 	    default:
